@@ -56,7 +56,6 @@ const xpcomFilesLocal = [
 	'annotate',
 	'attachments',
 	'cite',
-	'commons',
 	'cookieSandbox',
 	'data_access',
 	'data/dataObjects',
@@ -78,7 +77,6 @@ const xpcomFilesLocal = [
 	'data/tags',
 	'db',
 	'duplicates',
-	'enstyle',
 	'fulltext',
 	'id',
 	'integration',
@@ -95,12 +93,16 @@ const xpcomFilesLocal = [
 	'style',
 	'sync',
 	'storage',
-	'storage/session',
+	'storage/streamListener',
+	'storage/queueManager',
+	'storage/queue',
+	'storage/request',
+	'storage/mode',
 	'storage/zfs',
 	'storage/webdav',
+	'syncedSettings',
 	'timeline',
 	'uri',
-	'zeroconf',
 	'translation/translate_item',
 	'translation/translator',
 	'server_connector'
@@ -162,11 +164,11 @@ ZoteroContext.prototype = {
 	 */
 	"switchConnectorMode":function(isConnector) {
 		if(isConnector !== this.isConnector) {
-			zContext.Zotero.shutdown();
-			
-			// create a new zContext
-			makeZoteroContext(isConnector);
-			zContext.Zotero.init();
+			zContext.Zotero.shutdown().then(function() {
+				// create a new zContext
+				makeZoteroContext(isConnector);
+				zContext.Zotero.init();
+			}).done();
 		}
 		
 		return zContext;
@@ -195,23 +197,41 @@ function makeZoteroContext(isConnector) {
 		zContext.Zotero = function() {};
 	}
 	
+	var subscriptLoader = Cc["@mozilla.org/moz/jssubscript-loader;1"].getService(Ci.mozIJSSubScriptLoader);
+	
 	// Load zotero.js first
-	Cc["@mozilla.org/moz/jssubscript-loader;1"]
-		.getService(Ci.mozIJSSubScriptLoader)
-		.loadSubScript("chrome://zotero/content/xpcom/" + xpcomFilesAll[0] + ".js", zContext);
+	subscriptLoader.loadSubScript("chrome://zotero/content/xpcom/" + xpcomFilesAll[0] + ".js", zContext);
 	
 	// Load CiteProc into Zotero.CiteProc namespace
 	zContext.Zotero.CiteProc = {"Zotero":zContext.Zotero};
-	Cc["@mozilla.org/moz/jssubscript-loader;1"]
-		.getService(Ci.mozIJSSubScriptLoader)
-		.loadSubScript("chrome://zotero/content/xpcom/citeproc.js", zContext.Zotero.CiteProc);
+	subscriptLoader.loadSubScript("chrome://zotero/content/xpcom/citeproc.js", zContext.Zotero.CiteProc);
+	
+	// Load XRegExp object into Zotero.XRegExp
+	const xregexpFiles = [
+		/**Core functions**/
+		'xregexp',
+	
+		/**Addons**/
+		'addons/build',												//adds ability to "build regular expressions using named subpatterns, for readability and pattern reuse"
+		'addons/matchrecursive',							//adds ability to "match recursive constructs using XRegExp pattern strings as left and right delimiters"
+	
+		/**Unicode support**/
+		'addons/unicode/unicode-base',				//required for all other unicode packages. Adds \p{Letter} category
+	
+		//'addons/unicode/unicode-blocks',			//adds support for all Unicode blocks (e.g. InArabic, InCyrillic_Extended_A, etc.)
+		'addons/unicode/unicode-categories',	//adds support for all Unicode categories (e.g. Punctuation, Lowercase_Letter, etc.)
+		//'addons/unicode/unicode-properties',	//adds Level 1 Unicode properties (e.g. Uppercase, White_Space, etc.)
+		//'addons/unicode/unicode-scripts'			//adds support for all Unicode scripts (e.g. Gujarati, Cyrillic, etc.)
+		'addons/unicode/unicode-zotero'				//adds support for some Unicode categories used in Zotero
+	];
+	for (var i=0; i<xregexpFiles.length; i++) {
+		subscriptLoader.loadSubScript("chrome://zotero/content/xpcom/xregexp/" + xregexpFiles[i] + ".js", zContext);
+	}
 	
 	// Load remaining xpcomFiles
 	for (var i=1; i<xpcomFilesAll.length; i++) {
 		try {
-			Cc["@mozilla.org/moz/jssubscript-loader;1"]
-				.getService(Ci.mozIJSSubScriptLoader)
-				.loadSubScript("chrome://zotero/content/xpcom/" + xpcomFilesAll[i] + ".js", zContext);
+			subscriptLoader.loadSubScript("chrome://zotero/content/xpcom/" + xpcomFilesAll[i] + ".js", zContext);
 		}
 		catch (e) {
 			Components.utils.reportError("Error loading " + xpcomFilesAll[i] + ".js", zContext);
@@ -222,9 +242,7 @@ function makeZoteroContext(isConnector) {
 	// Load xpcomFiles for specific mode
 	for each(var xpcomFile in (isConnector ? xpcomFilesConnector : xpcomFilesLocal)) {
 		try {
-			Cc["@mozilla.org/moz/jssubscript-loader;1"]
-				.getService(Ci.mozIJSSubScriptLoader)
-				.loadSubScript("chrome://zotero/content/xpcom/" + xpcomFile + ".js", zContext);
+			subscriptLoader.loadSubScript("chrome://zotero/content/xpcom/" + xpcomFile + ".js", zContext);
 		}
 		catch (e) {
 			Components.utils.reportError("Error loading " + xpcomFile + ".js", zContext);
@@ -234,33 +252,27 @@ function makeZoteroContext(isConnector) {
 	
 	// Load RDF files into Zotero.RDF.AJAW namespace (easier than modifying all of the references)
 	const rdfXpcomFiles = [
+		'rdf/init',
 		'rdf/uri',
 		'rdf/term',
 		'rdf/identity',
 		'rdf/match',
 		'rdf/n3parser',
 		'rdf/rdfparser',
-		'rdf/serialize',
-		'rdf'
+		'rdf/serialize'
 	];
-	zContext.Zotero.RDF = {AJAW:{Zotero:zContext.Zotero}};
+	zContext.Zotero.RDF = {Zotero:zContext.Zotero};
 	for (var i=0; i<rdfXpcomFiles.length; i++) {
-		Cc["@mozilla.org/moz/jssubscript-loader;1"]
-			.getService(Ci.mozIJSSubScriptLoader)
-			.loadSubScript("chrome://zotero/content/xpcom/" + rdfXpcomFiles[i] + ".js", zContext.Zotero.RDF.AJAW);
+		subscriptLoader.loadSubScript("chrome://zotero/content/xpcom/" + rdfXpcomFiles[i] + ".js", zContext.Zotero.RDF);
 	}
 	
 	if(isStandalone()) {
 		// If isStandalone, load standalone.js
-		Cc["@mozilla.org/moz/jssubscript-loader;1"]
-			.getService(Ci.mozIJSSubScriptLoader)
-			.loadSubScript("chrome://zotero/content/xpcom/standalone.js", zContext);
+		subscriptLoader.loadSubScript("chrome://zotero/content/xpcom/standalone.js", zContext);
 	}
 	
 	// load nsTransferable (query: do we still use this?)
-	Cc["@mozilla.org/moz/jssubscript-loader;1"]
-		.getService(Ci.mozIJSSubScriptLoader)
-		.loadSubScript("chrome://global/content/nsTransferable.js", zContext);
+	subscriptLoader.loadSubScript("chrome://global/content/nsTransferable.js", zContext);
 	
 	// add connector-related properties
 	zContext.Zotero.isConnector = isConnector;
@@ -280,16 +292,11 @@ function ZoteroService() {
 			try {
 				zContext.Zotero.init();
 			} catch(e) {
-				if(e === "ZOTERO_SHOULD_START_AS_CONNECTOR") {
-					// if Zotero should start as a connector, reload it
-					zContext.Zotero.shutdown();
+				// if Zotero should start as a connector, reload it
+				zContext.Zotero.shutdown().then(function() {
 					makeZoteroContext(true);
 					zContext.Zotero.init();
-				} else {
-					dump(e.toSource());
-					Components.utils.reportError(e);
-					throw e;
-				}
+				}).done();
 			}
 		}
 		isFirstLoadThisSession = false;	// no longer first load
@@ -373,7 +380,7 @@ ZoteroCommandLineHandler.prototype = {
 							.createInstance(Components.interfaces.nsIProtocolHandler).newChannel(uri);
 					}
 				} else {
-					Zotero.debug("Not handling URL: "+uri.spec);
+					this.Zotero.debug("Not handling URL: "+uri.spec);
 				}
 			}
 			
@@ -389,19 +396,30 @@ ZoteroCommandLineHandler.prototype = {
 					this.Zotero.Styles.install(file);
 				} else {
 					// Ask before importing
+					var checkState = {"value":this.Zotero.Prefs.get('import.createNewCollection.fromFileOpenHandler')};
 					if(Components.classes["@mozilla.org/embedcomp/prompt-service;1"]
 							.getService(Components.interfaces.nsIPromptService)
-							.confirm(null, this.Zotero.getString('ingester.importFile.title'),
-							this.Zotero.getString('ingester.importFile.text', [file.leafName]))) {
+							.confirmCheck(null, this.Zotero.getString('ingester.importFile.title'),
+							this.Zotero.getString('ingester.importFile.text', [file.leafName]),
+							this.Zotero.getString('ingester.importFile.intoNewCollection'), 
+							checkState)) {
 						// Perform file import in front window
 						var wm = Components.classes["@mozilla.org/appshell/window-mediator;1"]
 										   .getService(Components.interfaces.nsIWindowMediator);
 						var browserWindow = wm.getMostRecentWindow("navigator:browser");
-						browserWindow.Zotero_File_Interface.importFile(file);
+						browserWindow.Zotero_File_Interface.importFile(file, checkState.value);
+						this.Zotero.Prefs.set('import.createNewCollection.fromFileOpenHandler', checkState.value);
 					}
 				}
 			}
 		}
+		// handler to open Zotero pane at startup in Zotero for Firefox
+		else {
+			var zPaneOpen = cmdLine.handleFlag("ZoteroPaneOpen", false);
+			if (zPaneOpen) {
+                this.Zotero.openPane = true;
+            }
+        }
 	},
 	
 	contractID: "@mozilla.org/commandlinehandler/general-startup;1?type=zotero",
