@@ -6,6 +6,8 @@
 pref("extensions.zotero.firstRun2", true);
 pref("extensions.zotero@chnm.gmu.edu.description", "chrome://zotero/locale/zotero.properties");
 
+pref("extensions.zotero.saveRelativeAttachmentPath", false);
+pref("extensions.zotero.baseAttachmentPath", '');
 pref("extensions.zotero.useDataDir", false);
 pref("extensions.zotero.dataDir", '');
 pref("extensions.zotero.lastDataDir", '');
@@ -19,6 +21,7 @@ pref("extensions.zotero.debug.level",5);
 pref("extensions.zotero.debug.time", false);
 pref("extensions.zotero.automaticScraperUpdates",true);
 pref("extensions.zotero.zoteroDotOrgVersionHeader", true);
+pref("extensions.zotero.triggerProxyAuthentication", true);
 pref("extensions.zotero.cacheTranslatorData",true);
 pref("extensions.zotero.showIn", 1);
 pref("extensions.zotero.statusBarIcon", 2);
@@ -44,6 +47,7 @@ pref("extensions.zotero.viewOnDoubleClick", true);
 pref("extensions.zotero.groups.copyChildLinks", true);
 pref("extensions.zotero.groups.copyChildFileAttachments", true);
 pref("extensions.zotero.groups.copyChildNotes", true);
+pref("extensions.zotero.groups.copyTags", true);
 
 pref("extensions.zotero.backup.numBackups", 2);
 pref("extensions.zotero.backup.interval", 1440);
@@ -59,17 +63,17 @@ pref("extensions.zotero.lastLongTagDelimiter", ";");
 pref("extensions.zotero.tagCloud", false);
 
 // Keyboard shortcuts
-pref("extensions.zotero.keys.overrideGlobal", false);
 pref("extensions.zotero.keys.openZotero", 'Z');
 pref("extensions.zotero.keys.toggleFullscreen", 'F');
-pref("extensions.zotero.keys.library", 'L');
-pref("extensions.zotero.keys.quicksearch", 'K');
+pref("extensions.zotero.keys.saveToZotero", 'S');
 pref("extensions.zotero.keys.newItem", 'N');
 pref("extensions.zotero.keys.newNote", 'O');
-pref("extensions.zotero.keys.toggleTagSelector", 'T');
+pref("extensions.zotero.keys.importFromClipboard", 'V');
+pref("extensions.zotero.keys.library", 'L');
+pref("extensions.zotero.keys.quicksearch", 'K');
 pref("extensions.zotero.keys.copySelectedItemCitationsToClipboard", 'A');
 pref("extensions.zotero.keys.copySelectedItemsToClipboard", 'C');
-pref("extensions.zotero.keys.importFromClipboard", 'V');
+pref("extensions.zotero.keys.toggleTagSelector", 'T');
 
 // Fulltext indexing
 pref("extensions.zotero.fulltext.textMaxLength", 500000);
@@ -91,9 +95,11 @@ pref("extensions.zotero.export.translatorSettings", 'true,false');
 pref("extensions.zotero.export.lastStyle", 'http://www.zotero.org/styles/chicago-note-bibliography');
 pref("extensions.zotero.export.bibliographySettings", 'save-as-rtf');
 pref("extensions.zotero.export.bibliographyLocale", '');
-pref("extensions.zotero.export.citePaperJournalArticleURL", false);
 pref("extensions.zotero.export.displayCharsetOption", false);
+pref("extensions.zotero.export.citePaperJournalArticleURL", false);
+pref("extensions.zotero.cite.automaticJournalAbbreviations", true);
 pref("extensions.zotero.import.charset", "auto");
+pref("extensions.zotero.import.createNewCollection.fromFileOpenHandler", true);
 pref("extensions.zotero.rtfScan.lastInputFile", "");
 pref("extensions.zotero.rtfScan.lastOutputFile", "");
 
@@ -117,11 +123,6 @@ pref("extensions.zotero.httpServer.port", 23119);	// ascii "ZO"
 // Zeroconf
 pref("extensions.zotero.zeroconf.server.enabled", false);
 
-// Zotero Commons
-pref("extensions.zotero.commons.enabled", false);
-pref("extensions.zotero.commons.accessKey", '');
-pref("extensions.zotero.commons.secretKey", '');
-
 // Annotation settings
 pref("extensions.zotero.annotations.warnOnClose", true);
 
@@ -139,6 +140,8 @@ pref("extensions.zotero.sync.storage.maxDownloads", 4);
 pref("extensions.zotero.sync.storage.maxUploads", 2);
 pref("extensions.zotero.sync.storage.deleteDelayDays", 30);
 pref("extensions.zotero.sync.storage.groups.enabled", true);
+pref("extensions.zotero.sync.storage.downloadMode.personal", "on-sync");
+pref("extensions.zotero.sync.storage.downloadMode.groups", "on-sync");
 
 // Proxy
 pref("extensions.zotero.proxies.autoRecognize", true);
@@ -165,3 +168,9 @@ pref("extensions.zotero.connector.repo.lastCheck.repoTime", 0);
 // File/URL opening executable if launch() fails
 pref("extensions.zotero.fallbackLauncher.unix", "/usr/bin/xdg-open");
 pref("extensions.zotero.fallbackLauncher.windows", "");
+
+//Translators
+pref("extensions.zotero.translators.attachSupplementary", false);
+pref("extensions.zotero.translators.supplementaryAsLink", false);
+pref("extensions.zotero.translators.RIS.import.ignoreUnknown", false);
+pref("extensions.zotero.translators.RIS.import.keepID", false);
